summaryrefslogtreecommitdiffstats
path: root/plugin/plugintest/api.go
diff options
context:
space:
mode:
Diffstat (limited to 'plugin/plugintest/api.go')
-rw-r--r--plugin/plugintest/api.go28
1 files changed, 14 insertions, 14 deletions
diff --git a/plugin/plugintest/api.go b/plugin/plugintest/api.go
index 473ef6d2b..70e90df4b 100644
--- a/plugin/plugintest/api.go
+++ b/plugin/plugintest/api.go
@@ -308,13 +308,13 @@ func (_m *API) GetChannel(channelId string) (*model.Channel, *model.AppError) {
return r0, r1
}
-// GetChannelByName provides a mock function with given fields: teamId, name
-func (_m *API) GetChannelByName(teamId string, name string) (*model.Channel, *model.AppError) {
- ret := _m.Called(teamId, name)
+// GetChannelByName provides a mock function with given fields: teamId, name, includeDeleted
+func (_m *API) GetChannelByName(teamId string, name string, includeDeleted bool) (*model.Channel, *model.AppError) {
+ ret := _m.Called(teamId, name, includeDeleted)
var r0 *model.Channel
- if rf, ok := ret.Get(0).(func(string, string) *model.Channel); ok {
- r0 = rf(teamId, name)
+ if rf, ok := ret.Get(0).(func(string, string, bool) *model.Channel); ok {
+ r0 = rf(teamId, name, includeDeleted)
} else {
if ret.Get(0) != nil {
r0 = ret.Get(0).(*model.Channel)
@@ -322,8 +322,8 @@ func (_m *API) GetChannelByName(teamId string, name string) (*model.Channel, *mo
}
var r1 *model.AppError
- if rf, ok := ret.Get(1).(func(string, string) *model.AppError); ok {
- r1 = rf(teamId, name)
+ if rf, ok := ret.Get(1).(func(string, string, bool) *model.AppError); ok {
+ r1 = rf(teamId, name, includeDeleted)
} else {
if ret.Get(1) != nil {
r1 = ret.Get(1).(*model.AppError)
@@ -333,13 +333,13 @@ func (_m *API) GetChannelByName(teamId string, name string) (*model.Channel, *mo
return r0, r1
}
-// GetChannelByNameForTeamName provides a mock function with given fields: teamName, channelName
-func (_m *API) GetChannelByNameForTeamName(teamName string, channelName string) (*model.Channel, *model.AppError) {
- ret := _m.Called(teamName, channelName)
+// GetChannelByNameForTeamName provides a mock function with given fields: teamName, channelName, includeDeleted
+func (_m *API) GetChannelByNameForTeamName(teamName string, channelName string, includeDeleted bool) (*model.Channel, *model.AppError) {
+ ret := _m.Called(teamName, channelName, includeDeleted)
var r0 *model.Channel
- if rf, ok := ret.Get(0).(func(string, string) *model.Channel); ok {
- r0 = rf(teamName, channelName)
+ if rf, ok := ret.Get(0).(func(string, string, bool) *model.Channel); ok {
+ r0 = rf(teamName, channelName, includeDeleted)
} else {
if ret.Get(0) != nil {
r0 = ret.Get(0).(*model.Channel)
@@ -347,8 +347,8 @@ func (_m *API) GetChannelByNameForTeamName(teamName string, channelName string)
}
var r1 *model.AppError
- if rf, ok := ret.Get(1).(func(string, string) *model.AppError); ok {
- r1 = rf(teamName, channelName)
+ if rf, ok := ret.Get(1).(func(string, string, bool) *model.AppError); ok {
+ r1 = rf(teamName, channelName, includeDeleted)
} else {
if ret.Get(1) != nil {
r1 = ret.Get(1).(*model.AppError)